@@ -11,6 +11,18 @@ func (issue *Issue) ExportData(fields []string) map[string]interface{} {
 
 	for _, f := range fields {
 		switch f {
+		case "author":
+			author := map[string]interface{}{
+				"is_bot": issue.Author.IsBot(),
+			}
+			if issue.Author.IsBot() {
+				author["login"] = "app/" + issue.Author.Login
+			} else {
+				author["login"] = issue.Author.Login
+				author["name"] = issue.Author.Name
+				author["id"] = issue.Author.ID
+			}
+			data[f] = author
 		case "comments":
 			data[f] = issue.Comments.Nodes
 		case "assignees":
@@ -34,11 +46,46 @@ func (pr *PullRequest) ExportData(fields []string) map[string]interface{} {
 
 	for _, f := range fields {
 		switch f {
+		case "author":
+			author := map[string]interface{}{
+				"is_bot": pr.Author.IsBot(),
+			}
+			if pr.Author.IsBot() {
+				author["login"] = "app/" + pr.Author.Login
+			} else {
+				author["login"] = pr.Author.Login
+				author["name"] = pr.Author.Name
+				author["id"] = pr.Author.ID
+			}
+			data[f] = author
 		case "headRepository":
 			data[f] = pr.HeadRepository
 		case "statusCheckRollup":
 			if n := pr.StatusCheckRollup.Nodes; len(n) > 0 {
-				data[f] = n[0].Commit.StatusCheckRollup.Contexts.Nodes
+				checks := make([]interface{}, 0, len(n[0].Commit.StatusCheckRollup.Contexts.Nodes))
+				for _, c := range n[0].Commit.StatusCheckRollup.Contexts.Nodes {
+					if c.TypeName == "CheckRun" {
+						checks = append(checks, map[string]interface{}{
+							"__typename":   c.TypeName,
+							"name":         c.Name,
+							"workflowName": c.CheckSuite.WorkflowRun.Workflow.Name,
+							"status":       c.Status,
+							"conclusion":   c.Conclusion,
+							"startedAt":    c.StartedAt,
+							"completedAt":  c.CompletedAt,
+							"detailsUrl":   c.DetailsURL,
+						})
+					} else {
+						checks = append(checks, map[string]interface{}{
+							"__typename": c.TypeName,
+							"context":    c.Context,
+							"state":      c.State,
+							"targetUrl":  c.TargetURL,
+							"startedAt":  c.CreatedAt,
+						})
+					}
+				}
+				data[f] = checks
 			} else {
 				data[f] = nil
 			}
