@@ -30,6 +30,7 @@ type PullRequestReviews struct {
 }
 
 type PullRequestReview struct {
+	ID                  string         `json:"id"`
 	Author              Author         `json:"author"`
 	AuthorAssociation   string         `json:"authorAssociation"`
 	Body                string         `json:"body"`
@@ -38,6 +39,7 @@ type PullRequestReview struct {
 	ReactionGroups      ReactionGroups `json:"reactionGroups"`
 	State               string         `json:"state"`
 	URL                 string         `json:"url,omitempty"`
+	Commit              Commit         `json:"commit"`
 }
 
 func AddReview(client *Client, repo ghrepo.Interface, pr *PullRequest, input *PullRequestReviewInput) error {
@@ -67,6 +69,10 @@ func AddReview(client *Client, repo ghrepo.Interface, pr *PullRequest, input *Pu
 	return client.Mutate(repo.RepoHost(), "PullRequestReviewAdd", &mutation, variables)
 }
 
+func (prr PullRequestReview) Identifier() string {
+	return prr.ID
+}
+
 func (prr PullRequestReview) AuthorLogin() string {
 	return prr.Author.Login
 }
