@@ -2,8 +2,8 @@ package api
 
 import (
 	"bytes"
-	"context"
 	"encoding/json"
+	"errors"
 	"fmt"
 	"io"
 	"net/http"
@@ -14,6 +14,7 @@ import (
 	"github.com/cli/cli/v2/internal/ghinstance"
 
 	"github.com/cli/cli/v2/internal/ghrepo"
+	ghAPI "github.com/cli/go-gh/pkg/api"
 	"github.com/shurcooL/githubv4"
 )
 
@@ -254,11 +255,13 @@ func FetchRepository(client *Client, repo ghrepo.Interface, fields []string) (*R
 	// The GraphQL API should have returned an error in case of a missing repository, but this isn't
 	// guaranteed to happen when an authentication token with insufficient permissions is being used.
 	if result.Repository == nil {
-		return nil, GraphQLErrorResponse{
-			Errors: []GraphQLError{{
-				Type:    "NOT_FOUND",
-				Message: fmt.Sprintf("Could not resolve to a Repository with the name '%s/%s'.", repo.RepoOwner(), repo.RepoName()),
-			}},
+		return nil, GraphQLError{
+			GQLError: ghAPI.GQLError{
+				Errors: []ghAPI.GQLErrorItem{{
+					Type:    "NOT_FOUND",
+					Message: fmt.Sprintf("Could not resolve to a Repository with the name '%s/%s'.", repo.RepoOwner(), repo.RepoName()),
+				}},
+			},
 		}
 	}
 
@@ -305,11 +308,13 @@ func GitHubRepo(client *Client, repo ghrepo.Interface) (*Repository, error) {
 	// The GraphQL API should have returned an error in case of a missing repository, but this isn't
 	// guaranteed to happen when an authentication token with insufficient permissions is being used.
 	if result.Repository == nil {
-		return nil, GraphQLErrorResponse{
-			Errors: []GraphQLError{{
-				Type:    "NOT_FOUND",
-				Message: fmt.Sprintf("Could not resolve to a Repository with the name '%s/%s'.", repo.RepoOwner(), repo.RepoName()),
-			}},
+		return nil, GraphQLError{
+			GQLError: ghAPI.GQLError{
+				Errors: []ghAPI.GQLErrorItem{{
+					Type:    "NOT_FOUND",
+					Message: fmt.Sprintf("Could not resolve to a Repository with the name '%s/%s'.", repo.RepoOwner(), repo.RepoName()),
+				}},
+			},
 		}
 	}
 
@@ -359,8 +364,7 @@ func RepoParent(client *Client, repo ghrepo.Interface) (ghrepo.Interface, error)
 		"name":  githubv4.String(repo.RepoName()),
 	}
 
-	gql := graphQLClient(client.http, repo.RepoHost())
-	err := gql.QueryNamed(context.Background(), "RepositoryFindParent", &query, variables)
+	err := client.Query(repo.RepoHost(), "RepositoryFindParent", &query, variables)
 	if err != nil {
 		return nil, err
 	}
@@ -419,8 +423,8 @@ func RepoNetwork(client *Client, repos []ghrepo.Interface) (RepoNetworkResult, e
 		%s
 	}
 	`, strings.Join(queries, "")), nil, &graphqlResult)
-	graphqlError, isGraphQLError := err.(*GraphQLErrorResponse)
-	if isGraphQLError {
+	var graphqlError GraphQLError
+	if errors.As(err, &graphqlError) {
 		// If the only errors are that certain repositories are not found,
 		// continue processing this response instead of returning an error
 		tolerated := true
@@ -497,13 +501,16 @@ type repositoryV3 struct {
 }
 
 // ForkRepo forks the repository on GitHub and returns the new repository
-func ForkRepo(client *Client, repo ghrepo.Interface, org string) (*Repository, error) {
+func ForkRepo(client *Client, repo ghrepo.Interface, org, newName string) (*Repository, error) {
 	path := fmt.Sprintf("repos/%s/forks", ghrepo.FullName(repo))
 
 	params := map[string]interface{}{}
 	if org != "" {
 		params["organization"] = org
 	}
+	if newName != "" {
+		params["name"] = newName
+	}
 
 	body := &bytes.Buffer{}
 	enc := json.NewEncoder(body)
@@ -581,8 +588,7 @@ func LastCommit(client *Client, repo ghrepo.Interface) (*Commit, error) {
 	variables := map[string]interface{}{
 		"owner": githubv4.String(repo.RepoOwner()), "repo": githubv4.String(repo.RepoName()),
 	}
-	gql := graphQLClient(client.http, repo.RepoHost())
-	if err := gql.QueryNamed(context.Background(), "LastCommit", &responseData, variables); err != nil {
+	if err := client.Query(repo.RepoHost(), "LastCommit", &responseData, variables); err != nil {
 		return nil, err
 	}
 	return &responseData.Repository.DefaultBranchRef.Target.Commit, nil
@@ -637,6 +643,7 @@ func RepoFindForks(client *Client, repo ghrepo.Interface, limit int) ([]*Reposit
 }
 
 type RepoMetadataResult struct {
+	CurrentLogin    string
 	AssignableUsers []RepoAssignee
 	Labels          []RepoLabel
 	Projects        []RepoProject
@@ -813,6 +820,17 @@ func RepoMetadata(client *Client, repo ghrepo.Interface, input RepoMetadataInput
 			errc <- nil
 		}()
 	}
+	if input.Reviewers {
+		count++
+		go func() {
+			login, err := CurrentLoginName(client, repo.RepoHost())
+			if err != nil {
+				err = fmt.Errorf("error fetching current login: %w", err)
+			}
+			result.CurrentLogin = login
+			errc <- err
+		}()
+	}
 	if input.Labels {
 		count++
 		go func() {
@@ -987,12 +1005,10 @@ func RepoProjects(client *Client, repo ghrepo.Interface) ([]RepoProject, error)
 		"endCursor": (*githubv4.String)(nil),
 	}
 
-	gql := graphQLClient(client.http, repo.RepoHost())
-
 	var projects []RepoProject
 	for {
 		var query responseData
-		err := gql.QueryNamed(context.Background(), "RepositoryProjectList", &query, variables)
+		err := client.Query(repo.RepoHost(), "RepositoryProjectList", &query, variables)
 		if err != nil {
 			return nil, err
 		}
@@ -1058,12 +1074,10 @@ func RepoAssignableUsers(client *Client, repo ghrepo.Interface) ([]RepoAssignee,
 		"endCursor": (*githubv4.String)(nil),
 	}
 
-	gql := graphQLClient(client.http, repo.RepoHost())
-
 	var users []RepoAssignee
 	for {
 		var query responseData
-		err := gql.QueryNamed(context.Background(), "RepositoryAssignableUsers", &query, variables)
+		err := client.Query(repo.RepoHost(), "RepositoryAssignableUsers", &query, variables)
 		if err != nil {
 			return nil, err
 		}
@@ -1103,12 +1117,10 @@ func RepoLabels(client *Client, repo ghrepo.Interface) ([]RepoLabel, error) {
 		"endCursor": (*githubv4.String)(nil),
 	}
 
-	gql := graphQLClient(client.http, repo.RepoHost())
-
 	var labels []RepoLabel
 	for {
 		var query responseData
-		err := gql.QueryNamed(context.Background(), "RepositoryLabelList", &query, variables)
+		err := client.Query(repo.RepoHost(), "RepositoryLabelList", &query, variables)
 		if err != nil {
 			return nil, err
 		}
@@ -1161,12 +1173,10 @@ func RepoMilestones(client *Client, repo ghrepo.Interface, state string) ([]Repo
 		"endCursor": (*githubv4.String)(nil),
 	}
 
-	gql := graphQLClient(client.http, repo.RepoHost())
-
 	var milestones []RepoMilestone
 	for {
 		var query responseData
-		err := gql.QueryNamed(context.Background(), "RepositoryMilestoneList", &query, variables)
+		err := client.Query(repo.RepoHost(), "RepositoryMilestoneList", &query, variables)
 		if err != nil {
 			return nil, err
 		}
