@@ -16,12 +16,12 @@ import (
 	"github.com/cli/cli/v2/internal/browser"
 	"github.com/cli/cli/v2/internal/config"
 	"github.com/cli/cli/v2/internal/ghrepo"
+	"github.com/cli/cli/v2/internal/prompter"
 	"github.com/cli/cli/v2/internal/run"
 	"github.com/cli/cli/v2/pkg/cmd/pr/shared"
 	"github.com/cli/cli/v2/pkg/cmdutil"
 	"github.com/cli/cli/v2/pkg/httpmock"
 	"github.com/cli/cli/v2/pkg/iostreams"
-	"github.com/cli/cli/v2/pkg/prompt"
 	"github.com/cli/cli/v2/test"
 	"github.com/google/shlex"
 	"github.com/stretchr/testify/assert"
@@ -187,7 +187,7 @@ func Test_createRun(t *testing.T) {
 		name           string
 		setup          func(*CreateOptions, *testing.T) func()
 		cmdStubs       func(*run.CommandStubber)
-		askStubs       func(*prompt.AskStubber) // TODO eventually migrate to PrompterMock
+		promptStubs    func(*prompter.PrompterMock)
 		httpStubs      func(*httpmock.Registry, *testing.T)
 		expectedOut    string
 		expectedErrOut string
@@ -268,8 +268,14 @@ func Test_createRun(t *testing.T) {
 				cs.Register(`git show-ref --verify -- HEAD refs/remotes/origin/feature`, 0, "")
 				cs.Register(`git push --set-upstream origin HEAD:feature`, 0, "")
 			},
-			askStubs: func(as *prompt.AskStubber) {
-				as.StubPrompt("Where should we push the 'feature' branch?").AnswerDefault()
+			promptStubs: func(pm *prompter.PrompterMock) {
+				pm.SelectFunc = func(p, _ string, opts []string) (int, error) {
+					if p == "Where should we push the 'feature' branch?" {
+						return 0, nil
+					} else {
+						return -1, prompter.NoSuchPromptErr(p)
+					}
+				}
 			},
 			expectedOut:    "https://github.com/OWNER/REPO/pull/12\n",
 			expectedErrOut: "\nCreating pull request for feature into master in OWNER/REPO\n\n",
@@ -309,8 +315,14 @@ func Test_createRun(t *testing.T) {
 				cs.Register(`git show-ref --verify -- HEAD refs/remotes/origin/feature`, 0, "")
 				cs.Register(`git push --set-upstream origin HEAD:feature`, 0, "")
 			},
-			askStubs: func(as *prompt.AskStubber) {
-				as.StubPrompt("Where should we push the 'feature' branch?").AnswerDefault()
+			promptStubs: func(pm *prompter.PrompterMock) {
+				pm.SelectFunc = func(p, _ string, opts []string) (int, error) {
+					if p == "Where should we push the 'feature' branch?" {
+						return 0, nil
+					} else {
+						return -1, prompter.NoSuchPromptErr(p)
+					}
+				}
 			},
 			expectedOut:    "https://github.com/OWNER/REPO/pull/12\n",
 			expectedErrOut: "\nCreating pull request for feature into master in OWNER/REPO\n\n",
@@ -354,10 +366,14 @@ func Test_createRun(t *testing.T) {
 				cs.Register(`git remote add -f fork https://github.com/monalisa/REPO.git`, 0, "")
 				cs.Register(`git push --set-upstream fork HEAD:feature`, 0, "")
 			},
-			askStubs: func(as *prompt.AskStubber) {
-				as.StubPrompt("Where should we push the 'feature' branch?").
-					AssertOptions([]string{"OWNER/REPO", "Create a fork of OWNER/REPO", "Skip pushing the branch", "Cancel"}).
-					AnswerWith("Create a fork of OWNER/REPO")
+			promptStubs: func(pm *prompter.PrompterMock) {
+				pm.SelectFunc = func(p, _ string, opts []string) (int, error) {
+					if p == "Where should we push the 'feature' branch?" {
+						return prompter.IndexFor(opts, "Create a fork of OWNER/REPO")
+					} else {
+						return -1, prompter.NoSuchPromptErr(p)
+					}
+				}
 			},
 			expectedOut:    "https://github.com/OWNER/REPO/pull/12\n",
 			expectedErrOut: "\nCreating pull request for monalisa:feature into master in OWNER/REPO\n\n",
@@ -482,14 +498,24 @@ func Test_createRun(t *testing.T) {
 			cmdStubs: func(cs *run.CommandStubber) {
 				cs.Register(`git( .+)? log( .+)? origin/master\.\.\.feature`, 0, "1234567890,commit 0\n2345678901,commit 1")
 			},
-			askStubs: func(as *prompt.AskStubber) {
-				as.StubPrompt("Choose a template").
-					AssertOptions([]string{"template1", "template2", "Open a blank pull request"}).
-					AnswerWith("template1")
-				as.StubPrompt("Body").AnswerDefault()
-				as.StubPrompt("What's next?").
-					AssertOptions([]string{"Submit", "Submit as draft", "Continue in browser", "Add metadata", "Cancel"}).
-					AnswerDefault()
+			promptStubs: func(pm *prompter.PrompterMock) {
+				pm.MarkdownEditorFunc = func(p, d string, ba bool) (string, error) {
+					if p == "Body" {
+						return d, nil
+					} else {
+						return "", prompter.NoSuchPromptErr(p)
+					}
+				}
+				pm.SelectFunc = func(p, _ string, opts []string) (int, error) {
+					switch p {
+					case "What's next?":
+						return 0, nil
+					case "Choose a template":
+						return prompter.IndexFor(opts, "template1")
+					default:
+						return -1, prompter.NoSuchPromptErr(p)
+					}
+				}
 			},
 			expectedOut:    "https://github.com/OWNER/REPO/pull/12\n",
 			expectedErrOut: "\nCreating pull request for feature into master in OWNER/REPO\n\n",
@@ -636,10 +662,14 @@ func Test_createRun(t *testing.T) {
 				cs.Register(`git( .+)? log( .+)? origin/master\.\.\.feature`, 0, "")
 				cs.Register(`git push --set-upstream origin HEAD:feature`, 0, "")
 			},
-			askStubs: func(as *prompt.AskStubber) {
-				as.StubPrompt("Where should we push the 'feature' branch?").
-					AssertOptions([]string{"OWNER/REPO", "Skip pushing the branch", "Cancel"}).
-					AnswerDefault()
+			promptStubs: func(pm *prompter.PrompterMock) {
+				pm.SelectFunc = func(p, _ string, opts []string) (int, error) {
+					if p == "Where should we push the 'feature' branch?" {
+						return 0, nil
+					} else {
+						return -1, prompter.NoSuchPromptErr(p)
+					}
+				}
 			},
 			expectedErrOut: "Opening github.com/OWNER/REPO/compare/master...feature in your browser.\n",
 			expectedBrowse: "https://github.com/OWNER/REPO/compare/master...feature?body=&expand=1",
@@ -685,8 +715,14 @@ func Test_createRun(t *testing.T) {
 				cs.Register(`git push --set-upstream origin HEAD:feature`, 0, "")
 
 			},
-			askStubs: func(as *prompt.AskStubber) {
-				as.StubPrompt("Where should we push the 'feature' branch?").AnswerDefault()
+			promptStubs: func(pm *prompter.PrompterMock) {
+				pm.SelectFunc = func(p, _ string, opts []string) (int, error) {
+					if p == "Where should we push the 'feature' branch?" {
+						return 0, nil
+					} else {
+						return -1, prompter.NoSuchPromptErr(p)
+					}
+				}
 			},
 			expectedErrOut: "Opening github.com/OWNER/REPO/compare/master...feature in your browser.\n",
 			expectedBrowse: "https://github.com/OWNER/REPO/compare/master...feature?body=&expand=1&projects=ORG%2F1",
@@ -725,12 +761,24 @@ func Test_createRun(t *testing.T) {
 				cs.Register(`git -c log.ShowSignature=false log --pretty=format:%H,%s --cherry origin/master...feature`, 0, "")
 				cs.Register(`git rev-parse --show-toplevel`, 0, "")
 			},
-			askStubs: func(as *prompt.AskStubber) {
-				as.StubPrompt("Choose a template").AnswerDefault()
-				as.StubPrompt("Body").AnswerDefault()
-				as.StubPrompt("What's next?").
-					AssertOptions([]string{"Submit", "Submit as draft", "Continue in browser", "Add metadata", "Cancel"}).
-					AnswerWith("Submit as draft")
+			promptStubs: func(pm *prompter.PrompterMock) {
+				pm.MarkdownEditorFunc = func(p, d string, ba bool) (string, error) {
+					if p == "Body" {
+						return d, nil
+					} else {
+						return "", prompter.NoSuchPromptErr(p)
+					}
+				}
+				pm.SelectFunc = func(p, _ string, opts []string) (int, error) {
+					switch p {
+					case "What's next?":
+						return prompter.IndexFor(opts, "Submit as draft")
+					case "Choose a template":
+						return 0, nil
+					default:
+						return -1, prompter.NoSuchPromptErr(p)
+					}
+				}
 			},
 			expectedOut:    "https://github.com/OWNER/REPO/pull/12\n",
 			expectedErrOut: "\nCreating pull request for feature into master in OWNER/REPO\n\n",
@@ -771,10 +819,28 @@ func Test_createRun(t *testing.T) {
 			cmdStubs: func(cs *run.CommandStubber) {
 				cs.Register(`git( .+)? log( .+)? origin/master\.\.\.feature`, 0, "")
 			},
-			askStubs: func(as *prompt.AskStubber) {
-				as.StubPrompt("Title").AnswerDefault()
-				as.StubPrompt("Body").AnswerDefault()
-				as.StubPrompt("What's next?").AnswerDefault()
+			promptStubs: func(pm *prompter.PrompterMock) {
+				pm.InputFunc = func(p, d string) (string, error) {
+					if p == "Title" {
+						return d, nil
+					} else {
+						return "", prompter.NoSuchPromptErr(p)
+					}
+				}
+				pm.MarkdownEditorFunc = func(p, d string, ba bool) (string, error) {
+					if p == "Body" {
+						return d, nil
+					} else {
+						return "", prompter.NoSuchPromptErr(p)
+					}
+				}
+				pm.SelectFunc = func(p, _ string, opts []string) (int, error) {
+					if p == "What's next?" {
+						return 0, nil
+					} else {
+						return -1, prompter.NoSuchPromptErr(p)
+					}
+				}
 			},
 			setup: func(opts *CreateOptions, t *testing.T) func() {
 				tmpfile, err := os.CreateTemp(t.TempDir(), "testrecover*")
@@ -848,11 +914,10 @@ func Test_createRun(t *testing.T) {
 				tt.httpStubs(reg, t)
 			}
 
-			//nolint:staticcheck // SA1019: prompt.InitAskStubber is deprecated: use NewAskStubber
-			ask, cleanupAsk := prompt.InitAskStubber()
-			defer cleanupAsk()
-			if tt.askStubs != nil {
-				tt.askStubs(ask)
+			pm := &prompter.PrompterMock{}
+
+			if tt.promptStubs != nil {
+				tt.promptStubs(pm)
 			}
 
 			cs, cmdTeardown := run.Stub()
@@ -864,6 +929,7 @@ func Test_createRun(t *testing.T) {
 			}
 
 			opts := CreateOptions{}
+			opts.Prompter = pm
 
 			ios, _, stdout, stderr := iostreams.Test()
 			// TODO do i need to bother with this
@@ -894,7 +960,10 @@ func Test_createRun(t *testing.T) {
 				return branch, nil
 			}
 			opts.Finder = shared.NewMockFinder(branch, nil, nil)
-			opts.GitClient = &git.Client{GitPath: "some/path/git"}
+			opts.GitClient = &git.Client{
+				GhPath:  "some/path/gh",
+				GitPath: "some/path/git",
+			}
 			cleanSetup := func() {}
 			if tt.setup != nil {
 				cleanSetup = tt.setup(&opts, t)
@@ -1011,7 +1080,10 @@ func Test_determineTrackingBranch(t *testing.T) {
 
 			tt.cmdStubs(cs)
 
-			gitClient := &git.Client{GitPath: "some/path/git"}
+			gitClient := &git.Client{
+				GhPath:  "some/path/gh",
+				GitPath: "some/path/git",
+			}
 			ref := determineTrackingBranch(gitClient, tt.remotes, "feature")
 			tt.assert(ref, t)
 		})
@@ -1089,3 +1161,5 @@ func Test_generateCompareURL(t *testing.T) {
 		})
 	}
 }
+
+// TODO interactive metadata tests once: 1) we have test utils for Prompter and 2) metadata questions use Prompter
